==> climetlab_wekeo_datasets-0.1.1.tar.gz: climetlab_wekeo_datasets-0.1.1/climetlab_wekeo_datasets/ecmwf/satellite_cloud_properties.py <==
#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_datasets.ecmwf.main import Main


class satellite_cloud_properties(Main):
    name = "EO:ECMWF:DAT:SATELLITE_CLOUD_PROPERTIES"
    dataset = "EO:ECMWF:DAT:SATELLITE_CLOUD_PROPERTIES"

    choices = [
        "product_family",
        "origin",
        "climate_data_record_type",
        "time_aggregation",
        "format_",
    ]

    string_selects = [
        "day",
        "month",
        "sensor_on_satellite",
        "variable",
        "year",
    ]

    @normalize(
        "day",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
            "16",
            "17",
            "18",
            "19",
            "20",
            "21",
            "22",
            "23",
            "24",
            "25",
            "26",
            "27",
            "28",
            "29",
            "30",
            "31",
        ],
        multiple=True,
    )
    @normalize(
        "month",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
        ],
        multiple=True,
    )
    @normalize(
        "sensor_on_satellite",
        [
            "aatsr_on_envisat",
            "atsr2_on_ers2",
            "avhrr_on_multiple_satellites",
            "slstr_on_sentinel_3a",
            "slstr_on_sentinel_3b",
        ],
        multiple=True,
    )
    @normalize(
        "variable",
        [
            "all_variables",
            "cloud_fraction",
            "cloud_physical_properties_of_the_ice_phase",
            "cloud_physical_properties_of_the_liquid_phase",
            "cloud_top_level",
        ],
        multiple=True,
    )
    @normalize(
        "year",
        [
            "1982",
            "1983",
            "1984",
            "1985",
            "1986",
            "1987",
            "1988",
            "1989",
            "1990",
            "1991",
            "1992",
            "1993",
            "1994",
            "1995",
            "1996",
            "1997",
            "1998",
            "1999",
            "2000",
            "2001",
            "2002",
            "2003",
            "2004",
            "2005",
            "2006",
            "2007",
            "2008",
            "2009",
            "2010",
            "2011",
            "2012",
            "2013",
            "2014",
            "2015",
            "2016",
            "2017",
            "2018",
            "2019",
            "2020",
            "2021",
        ],
        multiple=True,
    )
    @normalize("area", "bounding-box(list)")
    @normalize(
        "product_family",
        [
            "cci",
            "clara",
        ],
    )
    @normalize(
        "origin",
        [
            "c3s",
            "esa",
            "eumetsat",
        ],
    )
    @normalize(
        "climate_data_record_type",
        [
            "interim_climate_data_record",
            "thematic_climate_data_record",
        ],
    )
    @normalize(
        "time_aggregation",
        [
            "daily_mean",
            "monthly_mean",
        ],
    )
    @normalize(
        "format_",
        [
            "tgz",
            "zip",
        ],
    )
    def __init__(
        self,
        day,
        month,
        sensor_on_satellite,
        variable,
        year,
        area=None,
        product_family=None,
        origin=None,
        climate_data_record_type=None,
        time_aggregation=None,
        format_=None,
    ):
        super().__init__(
            day=day,
            month=month,
            sensor_on_satellite=sensor_on_satellite,
            variable=variable,
            year=year,
            area=area,
            product_family=product_family,
            origin=origin,
            climate_data_record_type=climate_data_record_type,
            time_aggregation=time_aggregation,
            format_=format_,
        )

==> climetlab_wekeo_datasets-0.3.0.tar.gz: climetlab_wekeo_datasets-0.3.0/climetlab_wekeo_datasets/ecmwf/satellite_cloud_properties.py <==
#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_datasets.ecmwf.main import Main


class satellite_cloud_properties(Main):
    name = "EO:ECMWF:DAT:SATELLITE_CLOUD_PROPERTIES"
    dataset = "EO:ECMWF:DAT:SATELLITE_CLOUD_PROPERTIES"

    @normalize(
        "climate_data_record_type",
        [
            "interim_climate_data_record",
            "thematic_climate_data_record",
        ],
    )
    @normalize(
        "day",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
            "16",
            "17",
            "18",
            "19",
            "20",
            "21",
            "22",
            "23",
            "24",
            "25",
            "26",
            "27",
            "28",
            "29",
            "30",
            "31",
        ],
        multiple=True,
    )
    @normalize(
        "month",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
        ],
        multiple=True,
    )
    @normalize(
        "origin",
        [
            "c3s",
            "esa",
            "eumetsat",
        ],
    )
    @normalize(
        "product_family",
        [
            "cci",
            "clara_a2",
            "clara_a3",
        ],
    )
    @normalize(
        "sensor_on_satellite",
        [
            "aatsr_on_envisat",
            "atsr2_on_ers2",
            "slstr_on_sentinel_3a",
            "slstr_on_sentinel_3a_3b",
            "slstr_on_sentinel_3b",
        ],
        multiple=True,
    )
    @normalize(
        "time_aggregation",
        [
            "daily_mean",
            "monthly_mean",
        ],
    )
    @normalize(
        "variable",
        [
            "all_variables",
            "cloud_fraction",
            "cloud_physical_properties_of_the_ice_phase",
            "cloud_physical_properties_of_the_liquid_phase",
            "cloud_top_level",
        ],
        multiple=True,
    )
    @normalize(
        "year",
        [
            "1979",
            "1980",
            "1981",
            "1982",
            "1983",
            "1984",
            "1985",
            "1986",
            "1987",
            "1988",
            "1989",
            "1990",
            "1991",
            "1992",
            "1993",
            "1994",
            "1995",
            "1996",
            "1997",
            "1998",
            "1999",
            "2000",
            "2001",
            "2002",
            "2003",
            "2004",
            "2005",
            "2006",
            "2007",
            "2008",
            "2009",
            "2010",
            "2011",
            "2012",
            "2013",
            "2014",
            "2015",
            "2016",
            "2017",
            "2018",
            "2019",
            "2020",
            "2021",
            "2022",
            "2023",
        ],
        multiple=True,
    )
    @normalize("bbox", "bounding-box(list)")
    @normalize(
        "format_",
        [
            "tgz",
            "zip",
        ],
    )
    def __init__(
        self,
        climate_data_record_type,
        day,
        month,
        origin,
        product_family,
        sensor_on_satellite,
        time_aggregation,
        variable,
        year,
        bbox=None,
        format_=None,
        limit=None,
    ):
        super().__init__(
            climate_data_record_type=climate_data_record_type,
            day=day,
            month=month,
            origin=origin,
            product_family=product_family,
            sensor_on_satellite=sensor_on_satellite,
            time_aggregation=time_aggregation,
            variable=variable,
            year=year,
            bbox=bbox,
            format_=format_,
            limit=limit,
        )
